==> pager-adapters-1.0.0-sources.jar: universum/studios/android/pager/adapter/PagerAdaptersConfig.java <==
/*
 * =================================================================================================
 *                             Copyright (C) 2016 Universum Studios
 * =================================================================================================
 *         Licensed under the Apache License, Version 2.0 or later (further "License" only).
 * -------------------------------------------------------------------------------------------------
 * You may use this file only in compliance with the License. More details and copy of this License
 * you may obtain at
 *
 * 		http://www.apache.org/licenses/LICENSE-2.0
 *
 * You can redistribute, modify or publish any part of the code written within this file but as it
 * is described in the License, the software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES or CONDITIONS OF ANY KIND.
 *
 * See the License for the specific language governing permissions and limitations under the License.
 * =================================================================================================
 */
package universum.studios.android.pager.adapter;

import android.util.Log;

/**
 * Configuration options for the Pager Adapters library.
 *
 * @author Martin Albedinsky
 */
public final class PagerAdaptersConfig {

	/**
	 * Flag indicating whether the <b>verbose</b> output for the Pager Adapters library trough log-cat
	 * is enabled or not.
	 *
	 * @see Log#v(String, String)
	 */
	public static boolean LOG_ENABLED = true;

	/**
	 * Flag indicating whether the <b>debug</b> output for the Pager Adapters library trough log-cat is
	 * enabled or not.
	 *
	 * @see Log#d(String, String)
	 */
	public static boolean DEBUG_LOG_ENABLED = false;
}

==> pager-adapters-2.0.2-sources.jar: universum/studios/android/pager/adapter/PagerAdaptersConfig.java <==
/*
 * =================================================================================================
 *                             Copyright (C) 2016 Universum Studios
 * =================================================================================================
 *         Licensed under the Apache License, Version 2.0 or later (further "License" only).
 * -------------------------------------------------------------------------------------------------
 * You may use this file only in compliance with the License. More details and copy of this License
 * you may obtain at
 *
 * 		http://www.apache.org/licenses/LICENSE-2.0
 *
 * You can redistribute, modify or publish any part of the code written within this file but as it
 * is described in the License, the software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES or CONDITIONS OF ANY KIND.
 *
 * See the License for the specific language governing permissions and limitations under the License.
 * =================================================================================================
 */
package universum.studios.android.pager.adapter;

import android.util.Log;

/**
 * <b>This class has been deprecated and will be removed in the next release.</b>
 * <p>
 * Configuration options for the Pager Adapters library.
 *
 * @author Martin Albedinsky
 * @deprecated Deprecated due to addition of {@link PagerAdaptersLogging} which should be used in order
 * to control logging output of the library instead.
 */
@Deprecated
public final class PagerAdaptersConfig {

	/**
	 * Flag indicating whether the <b>verbose</b> output for the Pager Adapters library trough log-cat
	 * is enabled or not.
	 *
	 * @see Log#v(String, String)
	 */
	public static boolean LOG_ENABLED = true;

	/**
	 * Flag indicating whether the <b>debug</b> output for the Pager Adapters library trough log-cat is
	 * enabled or not.
	 *
	 * @see Log#d(String, String)
	 */
	public static boolean DEBUG_LOG_ENABLED = false;

	/**
	 */
	private PagerAdaptersConfig() {
		// Creation of instances of this class is not publicly allowed.
	}
}
